@@ -3,9 +3,23 @@
 
 #include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4ui/libxfce4ui-alias.h>
-
 /* enumerations from "xfce-sm-client.h" */
+GType
+xfce_sm_client_error_enum_get_type(void)
+{
+    static GType type = 0;
 
+    if(!type) {
+        static const GEnumValue values[] = {
+            { XFCE_SM_CLIENT_ERROR_FAILED, "XFCE_SM_CLIENT_ERROR_FAILED", "failed" },
+            { XFCE_SM_CLIENT_ERROR_INVALID_CLIENT, "XFCE_SM_CLIENT_ERROR_INVALID_CLIENT", "invalid-client" },
+            { 0, NULL, NULL }
+	};
+	type = g_enum_register_static("XfceSmCLientErrorEnum", values);
+    }
+
+    return type;
+}
 GType
 xfce_sm_client_restart_style_get_type(void)
 {
@@ -22,7 +36,6 @@ xfce_sm_client_restart_style_get_type(void)
 
     return type;
 }
-
 GType
 xfce_sm_client_shutdown_hint_get_type(void)
 {
@@ -42,7 +55,6 @@ xfce_sm_client_shutdown_hint_get_type(void)
     return type;
 }
 
-
 #define __LIBXFCE4UI_ENUM_TYPES_C__
 #include <libxfce4ui/libxfce4ui-aliasdef.c>
 
