@@ -1,7 +1,5 @@
 #include <libxfce4ui/libxfce4ui-marshal.h>
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,21 +47,20 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
-/* BOOL:VOID (./libxfce4ui-marshal.list:1) */
+/* BOOLEAN:VOID (./libxfce4ui-marshal.list:1) */
 void
 _libxfce4ui_marshal_BOOLEAN__VOID (GClosure     *closure,
-                                   GValue       *return_value G_GNUC_UNUSED,
+                                   GValue       *return_value,
                                    guint         n_param_values,
                                    const GValue *param_values,
                                    gpointer      invocation_hint G_GNUC_UNUSED,
                                    gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
-                                                  gpointer     data2);
-  GMarshalFunc_BOOLEAN__VOID callback;
-  GCClosure *cc = (GCClosure*) closure;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer data1,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
   gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
