@@ -458,7 +458,7 @@ static const SECTION union { const guint8 data[3584]; const double alignment; vo
 } };
 
 static GStaticResource static_resource = { libxfce4ui_resource_data.data, sizeof (libxfce4ui_resource_data.data), NULL, NULL, NULL };
-extern GResource *libxfce4ui_get_resource (void);
+G_GNUC_INTERNAL GResource *libxfce4ui_get_resource (void);
 GResource *libxfce4ui_get_resource (void)
 {
   return g_static_resource_get_resource (&static_resource);
